﻿using ProjectAirFighter.Entities;

namespace ProjectAirFighter.Drawnings;

/// <summary>
/// Класс, отвечающий за прорисовку и перемещение объекта-сущности
/// </summary>
public class DrawningAirFighter : DrawningAirCraft
{
    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес</param>
    /// <param name="bodyColor">Основной цвет</param>
    /// <param name="additionalColor">Дополнительный цвет</param>
    /// <param name="pgo">Признак наличия ПГО</param>
    /// <param name="rockets">Признак наличия ракет</param>
    public DrawningAirFighter(int speed, double weight, Color bodyColor, Color additionalColor, bool pgo, bool rockets) : base(66, 74)
    {
        EntityAirCraft = new EntityAirFighter(speed, weight, bodyColor, additionalColor, pgo, rockets);
    }

    /// <summary>
    /// Конструктор для Extention
    /// </summary>
    /// <param name="airbus"></param>
    public DrawningAirFighter(EntityAirFighter aircraft) : base(66, 74)
    {
        EntityAirCraft = new EntityAirFighter(aircraft.Speed, aircraft.Weight, aircraft.BodyColor, aircraft.AdditionalColor, aircraft.Pgo, aircraft.Rockets);
    }
    public override void DrawTransport(Graphics g)
    {
        if (EntityAirCraft == null || EntityAirCraft is not EntityAirFighter airFighter || !_startPosX.HasValue || !_startPosY.HasValue)
        {
            return;
        }

        Pen pen = new(Color.Black);
        Brush additionalBrush = new SolidBrush(airFighter.AdditionalColor);

        //ПГО
        if (airFighter.Pgo)
        {
            Point[] pgo1 = new Point[] {
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 25},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 15},
            new Point { X = _startPosX.Value + 45, Y = _startPosY.Value + 25}
            };

            g.DrawPolygon(pen, pgo1);
            g.FillPolygon(additionalBrush, pgo1);

            Point[] pgo2 = new Point[] {
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 49},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 59},
            new Point { X = _startPosX.Value + 45, Y = _startPosY.Value + 49}
            };

            g.DrawPolygon(pen, pgo2);
            g.FillPolygon(additionalBrush, pgo2);
        }
        // ракеты
        if (airFighter.Rockets)
        {
            Point[] rocket1 = new Point[] {
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 71},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 74},
            new Point { X = _startPosX.Value + 45, Y = _startPosY.Value + 69},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 64}
            };

            g.DrawPolygon(pen, rocket1);
            g.FillPolygon(additionalBrush, rocket1);

            g.DrawRectangle(pen, _startPosX.Value + 35, _startPosY.Value + 67, 5, 4);
            g.FillRectangle(additionalBrush, _startPosX.Value + 35, _startPosY.Value + 67, 5, 4);

            Point[] rocket2 = new Point[] {
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value +7},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value + 10},
            new Point { X = _startPosX.Value + 45, Y = _startPosY.Value + 5},
            new Point { X = _startPosX.Value + 40, Y = _startPosY.Value}
            };

            g.DrawPolygon(pen, rocket2);
            g.FillPolygon(additionalBrush, rocket2);

            g.DrawRectangle(pen, _startPosX.Value + 35, _startPosY.Value + 3, 5, 4);
            g.FillRectangle(additionalBrush, _startPosX.Value + 35, _startPosY.Value + 3, 5, 4);
        }

        //обводка
        if (airFighter.Rockets)
        {
            g.DrawRectangle(pen, _startPosX.Value + 35, _startPosY.Value + 67, 5, 4);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 71, _startPosX.Value + 40, _startPosY.Value + 74);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 74, _startPosX.Value + 45, _startPosY.Value + 69);
            g.DrawLine(pen, _startPosX.Value + 45, _startPosY.Value + 69, _startPosX.Value + 40, _startPosY.Value + 64);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 64, _startPosX.Value + 40, _startPosY.Value + 71);


            g.DrawRectangle(pen, _startPosX.Value + 35, _startPosY.Value + 3, 5, 4);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 7, _startPosX.Value + 40, _startPosY.Value + 10);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 10, _startPosX.Value + 45, _startPosY.Value + 5);
            g.DrawLine(pen, _startPosX.Value + 45, _startPosY.Value + 5, _startPosX.Value + 40, _startPosY.Value);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value, _startPosX.Value + 40, _startPosY.Value + 7);
        }

        if (airFighter.Pgo)
        {
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 25, _startPosX.Value + 40, _startPosY.Value + 15);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 15, _startPosX.Value + 45, _startPosY.Value + 25);

            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 49, _startPosX.Value + 40, _startPosY.Value + 59);
            g.DrawLine(pen, _startPosX.Value + 40, _startPosY.Value + 59, _startPosX.Value + 45, _startPosY.Value + 49);
        }

        base.DrawTransport(g);
    }
}