﻿using ProjectAirFighter.Entities;

namespace ProjectAirFighter.Drawnings;

/// <summary>
/// Расширение для класса EntityAirCraft
/// </summary>
public static class ExtentionDrawningAirCraft
{
    /// <summary>
    /// Разделитель для записи информации по объекту в файл
    /// </summary>
    private static readonly string _separatorForObject = ":";

    /// <summary>
    /// Создание объекта из строки
    /// </summary>
    /// <param name="info">Строка с данными для создания объекта</param>
    /// <returns>Объект</returns>
    public static DrawningAirCraft? CreateDrawningAirCraft(this string info)
    {
        string[] strs = info.Split(_separatorForObject);
        EntityAirCraft? aircraft = EntityAirFighter.CreateEntityAirFighter(strs);
        if (aircraft != null)
        {
            return new DrawningAirFighter((EntityAirFighter)aircraft);
        }

        aircraft = EntityAirCraft.CreateEntityAirCraft(strs);
        if (aircraft != null)
        {
            return new DrawningAirCraft(aircraft);
        }

        return null;
    }

    /// <summary>
    /// Получение данных для сохранения в файл
    /// </summary>
    /// <param name="drawningAirCraft">Сохраняемый объект</param>
    /// <returns>Строка с данными по объекту</returns>
    public static string GetDataForSave(this DrawningAirCraft drawningAirCraft)
    {
        string[]? array = drawningAirCraft?.EntityAirCraft?.GetStringRepresentation();

        if (array == null)
        {
            return string.Empty;
        }

        return string.Join(_separatorForObject, array);
    }
}