﻿namespace ProjectAirFighter.Entities;
/// <summary>
/// Класс-сущность "Самолёт"
/// </summary>
public class EntityAirCraft
{
    /// <summary>
    /// Скорость
    /// </summary>
    public int Speed { get; private set; }

    /// <summary>
    /// Вес
    /// </summary>
    public double Weight { get; private set; }

    /// <summary>
    /// Основной цвет
    /// </summary>
    public Color BodyColor { get; private set; }
    public void SetBodyColor(Color color)
    {
        BodyColor = color;
    }
    /// <summary>
    /// Шаг перемещения самолёта
    /// </summary>
    public double Step => Speed * 100 / Weight;

    /// <summary>
    /// Конструктор сущности
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес самолёта</param>
    /// <param name="bodyColor">Основной цвет</param>
    public EntityAirCraft(int speed, double weight, Color bodyColor)
    {
        Speed = speed;
        Weight = weight;
        BodyColor = bodyColor;
    }

    /// <summary>
    /// Получение строк со значениями свойств объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public virtual string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityAirCraft), Speed.ToString(), Weight.ToString(), BodyColor.Name };
    }

    /// <summary>
    /// Создание объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityAirCraft? CreateEntityAirCraft(string[] strs)
    {
        if (strs.Length != 4 || strs[0] != nameof(EntityAirCraft))
        {
            return null;
        }

        return new EntityAirCraft(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]));
    }
}
