﻿namespace ProjectAirFighter.Entities;

/// <summary>
/// Класс-сущность "Истребитель"
/// </summary>
public class EntityAirFighter : EntityAirCraft
{
    /// <summary>
    /// Дополнительный цвет (для опциональных элементов)
    /// </summary>
    public Color AdditionalColor { get; private set; }
    public void SetAdditionalColor(Color color)
    {
        AdditionalColor = color;
    }
    /// <summary>
    /// Признак (опция) наличия Переднего Горизонтального Оперения(ПГО)
    /// </summary>
    public bool Pgo { get; private set; }

    /// <summary>
    /// Признак (опция) наличия ракет
    /// </summary>
    public bool Rockets { get; private set; }

    /// <summary>
    /// Инициализация полей объекта-класса истребителя
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес истребителя</param>
    /// <param name="bodyColor">Основной цвет</param>
    /// <param name="additionalColor">Дополнительный цвет</param>
    /// <param name="pgo">Признак наличия ПГО</param>
    /// <param name="rockets">Признак наличия ракет"</param>
    public EntityAirFighter(int speed, double weight, Color bodyColor, Color additionalColor, bool pgo, bool rockets) : base(speed, weight, bodyColor)
    {
        AdditionalColor = additionalColor;
        Pgo = pgo;
        Rockets = rockets;
    }

    /// <summary>
    /// Получение строк со значениями свойств продвинутого объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public override string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityAirFighter), Speed.ToString(), Weight.ToString(), BodyColor.Name, AdditionalColor.Name,
                        Pgo.ToString(), Rockets.ToString()};
    }

    /// <summary>
    /// Создание продвинутого объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityAirFighter? CreateEntityAirFighter(string[] strs)
    {
        if (strs.Length != 7 || strs[0] != nameof(EntityAirFighter))
        {
            return null;
        }
        return new EntityAirFighter(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]),
                                    Color.FromName(strs[4]), Convert.ToBoolean(strs[5]), Convert.ToBoolean(strs[6]));
    }
}