﻿using ProjectAirFighter.Drawnings;
using ProjectAirFighter.Entities;

namespace ProjectAirFighter;

/// <summary>
/// Форма конфигурации объекта
/// </summary>
public partial class FormAirCraftConfig : Form
{
    /// <summary>
    /// Объект - прорисовка самолёта
    /// </summary>
    private DrawningAirCraft? _aircraft;

    /// <summary>
	/// Событие для передачи объекта
	/// </summary>
	private event Action<DrawningAirCraft>? _aircraftDelegate;

    /// <summary>
    /// Конструктор
    /// </summary>
    public FormAirCraftConfig()
    {
        InitializeComponent();

        panelRed.MouseDown += Panel_MouseDown;
        panelGreen.MouseDown += Panel_MouseDown;
        panelBlue.MouseDown += Panel_MouseDown;
        panelYellow.MouseDown += Panel_MouseDown;
        panelWhite.MouseDown += Panel_MouseDown;
        panelGray.MouseDown += Panel_MouseDown;
        panelBlack.MouseDown += Panel_MouseDown;
        panelPurple.MouseDown += Panel_MouseDown;

        buttonCancel.Click += (sender, e) => Close();
        
    }

    /// <summary>
	/// Привязка внешнего метода к событию
	/// </summary>
	/// <param name="aircraftDelegate"></param>
	public void AddEvent(Action<DrawningAirCraft> aircraftDelegate)
    {
        _aircraftDelegate += aircraftDelegate;
    }

    /// <summary>
	/// Прорисовка объекта
	/// </summary>
    private void DrawObject()
    {
        Bitmap bmp = new(pictureBoxObject.Width, pictureBoxObject.Height);
        Graphics gr = Graphics.FromImage(bmp);
        _aircraft?.SetPictureSize(pictureBoxObject.Width, pictureBoxObject.Height);
        _aircraft?.SetPosition(15, 15);
        _aircraft?.DrawTransport(gr);
        pictureBoxObject.Image = bmp;
    }

    /// <summary>
	/// Передаем информацию при нажатии на Label
	/// </summary>
	/// <param name="sender"></param>
	/// <param name="e"></param>
	private void LabelObject_MouseDown(object sender, MouseEventArgs e)
    {
        (sender as Label)?.DoDragDrop((sender as Label)?.Name ?? string.Empty, DragDropEffects.Move | DragDropEffects.Copy);
    }

    /// <summary>
	/// Проверка получаемой информации (ее типа на соответствие требуемому)
	/// </summary>
	/// <param name="sender"></param>
	/// <param name="e"></param>
	private void PanelObject_DragEnter(object sender, DragEventArgs e)
    {
        e.Effect = e.Data?.GetDataPresent(DataFormats.Text) ?? false ? DragDropEffects.Copy : DragDropEffects.None;
    }

    /// <summary>
    /// Действия при приеме перетаскиваемой информации
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void PanelObject_DragDrop(object sender, DragEventArgs e)
    {
        switch (e.Data?.GetData(DataFormats.Text)?.ToString())
        {
            case "labelSimpleObject":
                _aircraft = new DrawningAirCraft((int)numericUpDownSpeed.Value, (double)numericUpDownWeight.Value, Color.White);
                break;
            case "labelModifiedObject":
                _aircraft = new DrawningAirFighter((int)numericUpDownSpeed.Value, (double)numericUpDownWeight.Value, Color.White,
                    Color.Black, checkBoxPgo.Checked, checkBoxRockets.Checked);
                break;
        }

        DrawObject();
    }

    /// <summary>
    /// Передаем информацию при нажатии на Panel
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void Panel_MouseDown(object? sender, MouseEventArgs e)
    {
        (sender as Control)?.DoDragDrop((sender as Control)?.BackColor!, DragDropEffects.Move | DragDropEffects.Copy);
    }
    private void LabelBodyColor_DragDrop(object sender, DragEventArgs e)
    {
        if (_aircraft == null) return;
        _aircraft.EntityAirCraft?.SetBodyColor((Color)e.Data.GetData(typeof(Color)));
        DrawObject();
    }
    private void LabelBodyColor_DragEnter(object sender, DragEventArgs e)
    {
        if (_aircraft != null && e.Data.GetDataPresent(typeof(Color))) e.Effect = DragDropEffects.Copy;
        else e.Effect = DragDropEffects.None;
    }
    private void LabelAdditionalColor_DragDrop(object sender, DragEventArgs e)
    {
        if (_aircraft != null && _aircraft.EntityAirCraft is EntityAirFighter _airfighter)
            _airfighter.SetAdditionalColor((Color)e.Data.GetData(typeof(Color)));
        DrawObject();
    }
    private void LabelAdditionalColor_DragEnter(object sender, DragEventArgs e)
    {
        if (_aircraft != null && e.Data.GetDataPresent(typeof(Color)) && _aircraft.EntityAirCraft is EntityAirFighter) e.Effect = DragDropEffects.Copy;
        else e.Effect = DragDropEffects.None;
    }

    /// <summary>
    /// Передача объекта
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void buttonAdd_Click(object sender, EventArgs e)
    {
        if (_aircraft != null)
        {
            _aircraftDelegate?.Invoke(_aircraft);
            Close();
        }
    }
}