﻿using ProjectAirFighter.Drawnings;
using ProjectAirFighter.MovementStrategy;

namespace ProjectAirFighter;

/// <summary>
/// Форма работы с объектом "Истребитель"
/// </summary>
public partial class FormAirFighter : Form
{
    /// <summary>
    /// Поле-объект для прорисовки объекта
    /// </summary>
    private DrawningAirCraft? _drawningAirCraft;

    /// <summary>
    /// Стратегия перемещения
    /// </summary>
    private AbstractStrategy? _strategy;

    /// <summary>
	/// Получение объекта 
	/// </summary>
	public DrawningAirCraft SetAirCraft
    {
        set
        {
            _drawningAirCraft = value;
            _drawningAirCraft.SetPictureSize(pictureBoxAirFighter.Width, pictureBoxAirFighter.Height);
            comboBoxStrategy.Enabled = true;
            _strategy = null;
            Draw();
        }
    }

    /// <summary>
    /// Конструктор формы
    /// </summary>
    public FormAirFighter()
    {
        InitializeComponent();
        _strategy = null;
    }

    /// <summary>
    /// Метод прорисовки истребителя
    /// </summary>
    private void Draw()
    {
        if (_drawningAirCraft == null)
        {
            return;
        }

        Bitmap bmp = new(pictureBoxAirFighter.Width, pictureBoxAirFighter.Height);
        Graphics gr = Graphics.FromImage(bmp);
        _drawningAirCraft.DrawTransport(gr);
        pictureBoxAirFighter.Image = bmp;
    }

    /// <summary>
    /// Перемещение объекта по форме (нажатие кнопок навигации)
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void ButtonMove_Click(object sender, EventArgs e)
    {
        if (_drawningAirCraft == null)
        {
            return;
        }

        string name = ((Button)sender)?.Name ?? string.Empty;
        bool result = false;
        switch (name)
        {
            case "buttonUp":
                result = _drawningAirCraft.MoveTransport(DirectionType.Up);
                break;
            case "buttonDown":
                result = _drawningAirCraft.MoveTransport(DirectionType.Down);
                break;
            case "buttonLeft":
                result = _drawningAirCraft.MoveTransport(DirectionType.Left);
                break;
            case "buttonRight":
                result = _drawningAirCraft.MoveTransport(DirectionType.Right);
                break;
        }

        if (result)
        {
            Draw();
        }
    }

    private void buttonStrategyStep_Click(object sender, EventArgs e)
    {
        if (_drawningAirCraft == null)
        {
            return;
        }

        if (comboBoxStrategy.Enabled)
        {
            _strategy = comboBoxStrategy.SelectedIndex switch
            {
                0 => new MoveToCenter(),
                1 => new MoveToBorder(),
                _ => null,
            };
            if (_strategy == null)
            {
                return;
            }
            _strategy.SetData(new MoveableAirCraft(_drawningAirCraft), pictureBoxAirFighter.Width, pictureBoxAirFighter.Height);
        }

        if (_strategy == null)
        {
            return;
        }

        comboBoxStrategy.Enabled = false;
        _strategy.MakeStep();
        Draw();

        if (_strategy.GetStatus() == StrategyStatus.Finish)
        {
            comboBoxStrategy.Enabled = true;
            _strategy = null;
        }
    }
}
