﻿using ProjectAirFighter.Drawnings;
using ProjectAirFighter.MovementStrategy;

/// <summary>
/// Класс-реализация IMoveableObject с использованием DrawningAirCraft
/// </summary>
public class MoveableAirCraft : IMoveableObject
{
    /// <summary>
    /// Поле-объект класса DrawningAirCraft или его наследника
    /// </summary>
    private readonly DrawningAirCraft? _airCraft = null;

    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="car">Объект класса DrawningAirCraft</param>
    public MoveableAirCraft(DrawningAirCraft airCraft)
    {
        _airCraft = airCraft;
    }

    public ObjectParameters? GetObjectPosition
    {
        get
        {
            if (_airCraft == null || _airCraft.EntityAirCraft == null || !_airCraft.GetPosX.HasValue || !_airCraft.GetPosY.HasValue)
            {
                return null;
            }
            return new ObjectParameters(_airCraft.GetPosX.Value, _airCraft.GetPosY.Value, _airCraft.GetWidth, _airCraft.GetHeight);
        }
    }

    public int GetStep => (int)(_airCraft?.EntityAirCraft?.Step ?? 0);

    public bool TryMoveObject(MovementDirection direction)
    {
        if (_airCraft == null || _airCraft.EntityAirCraft == null)
        {
            return false;
        }

        return _airCraft.MoveTransport(GetDirectionType(direction));
    }

    /// <summary>
    /// Конвертация из MovementDirection в DirectionType
    /// </summary>
    /// <param name="direction">MovementDirection</param>
    /// <returns>DirectionType</returns>
    private static DirectionType GetDirectionType(MovementDirection direction)
    {
        return direction switch
        {
            MovementDirection.Left => DirectionType.Left,
            MovementDirection.Right => DirectionType.Right,
            MovementDirection.Up => DirectionType.Up,
            MovementDirection.Down => DirectionType.Down,
            _ => DirectionType.Unknow,
        };
    }
}
